import 'package:verttice_ui/verttice_ui.dart';

import 'themed_locale_manager.dart';

/// Example To Use [ThemedLocale] In [ThemedApp]
/// ```
/// class AppLocaleKeys {
///   static final signIn = ThemedLocaleKey(en: 'signIn Message', heIL: 'כניסה');
/// }
/// ```
///
/// ```
/// String textWidget() {
///   return AppLocaleKeys.signIn.byLocale();
/// }
/// ```
class ThemedLocaleKey extends LocaleKeys {
  final String en;
  final String? enGB;
  final String? enUS;
  final String? heIL;

  ThemedLocaleKey({
    required this.en,
    this.enGB,
    this.enUS,
    this.heIL,
  });

  String get toLocale {
    final fromLocale = {
      ThemedLocale.en: en,
      ThemedLocale.heIL: heIL,
      ThemedLocale.enGB: enGB,
      ThemedLocale.enUS: enUS,
    }[locale];

    return fromLocale ?? en;
  }

  @override
  String toString() {
    return 'ThemedLocaleKey(en: $en, enGB: $enGB, enUS: $enUS, heIL: $heIL)';
  }

  ThemedLocaleKey copyWith({
    String? en,
    String? enGB,
    String? enUS,
    String? heIL,
  }) {
    return ThemedLocaleKey(
      en: en ?? this.en,
      enGB: enGB ?? this.enGB,
      enUS: enUS ?? this.enUS,
      heIL: heIL ?? this.heIL,
    );
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ThemedLocaleKey &&
        other.en == en &&
        other.enGB == enGB &&
        other.enUS == enUS &&
        other.heIL == heIL;
  }

  @override
  int get hashCode {
    return en.hashCode ^ enGB.hashCode ^ enUS.hashCode ^ heIL.hashCode;
  }
}
