import 'package:flutter/material.dart';
import 'package:verttice_ui/verttice_ui.dart';

enum ThemedLocale {
  en,
  enGB,
  enUS,
  heIL,
}

final Map<ThemedLocale, Locale> themedLocalToLocale = {
  ThemedLocale.en: const Locale(
    'en',
  ),
  ThemedLocale.enUS: const Locale('en', 'US'),
  ThemedLocale.enGB: const Locale('en', 'GB'),
  ThemedLocale.heIL: const Locale('he', 'IL'),
};

abstract class LocaleKeys {
  final ThemedLocale locale = VertticeUI.instance.localeManager.locale;
}

class ThemedLocaleManager {
  ThemedLocale _locale = ThemedLocale.en;
  List<ThemedLocale> _appSupportLocale = [ThemedLocale.en];
  void initLocale(ThemedLocale locale) {
    _locale = locale;
  }

  void setAppSupportLocale(List<ThemedLocale> appSupportLocale) =>
      _appSupportLocale = !appSupportLocale.contains(ThemedLocale.en)
          ? [...appSupportLocale, ThemedLocale.en]
          : _appSupportLocale;
  List<ThemedLocale> get appSupportLocale => _appSupportLocale;

  Locale get appLocale => themedLocalToLocale[_locale]!;

  ThemedLocale get locale => _locale;
}
