// 🎯 Dart imports:
import "dart:async";

// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:cross_connectivity/cross_connectivity.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:verttice_ui/verttice_ui.dart';

import 'package:wakelock/wakelock.dart';

final vertticeUISettingsProvider =
    StateNotifierProvider<VertticeUISettingsNotifier, VertticeUISettings>(
        (ref) {
  return VertticeUISettingsNotifier();
});

@immutable
class VertticeUISettings {
  final bool connectedToTheInternet;
  final bool keepDeviceAwake;

  const VertticeUISettings({
    this.connectedToTheInternet = false,
    this.keepDeviceAwake = true,
  });

  VertticeUISettings copyWith({
    bool? connectedToTheInternet,
    bool? keepDeviceAwake,
  }) {
    return VertticeUISettings(
      connectedToTheInternet:
          connectedToTheInternet ?? this.connectedToTheInternet,
      keepDeviceAwake: keepDeviceAwake ?? this.keepDeviceAwake,
    );
  }
}

class VertticeUISettingsNotifier extends StateNotifier<VertticeUISettings> {
  VertticeUISettingsNotifier() : super(const VertticeUISettings()) {
    _initConnectivity();
    _initDeviceAwake();
  }

  Future<void> setKeepDeviceAwake(bool val) async {
    final pref = await SharedPreferences.getInstance();
    await pref.setBool("awake", val);
    Wakelock.toggle(enable: val);
    state = state.copyWith(
      keepDeviceAwake: val,
    );
  }

  void setConnectToTheInternet(bool val) {
    state = state.copyWith(
      connectedToTheInternet: val,
    );
  }

  Future _initDeviceAwake() async {
    final pref = await SharedPreferences.getInstance();
    final awake = pref.getBool("awake");
    if (awake == null) {
      await pref.setBool("awake", true);
    }
    setKeepDeviceAwake(awake ?? true);
  }

  Future<void> _initConnectivity() async {
    final connectivityResult = await (Connectivity().checkConnectivity());
    setConnectToTheInternet(connectivityResult != ConnectivityStatus.none);
    Connectivity().onConnectivityChanged.listen((ConnectivityStatus result) {
      setConnectToTheInternet(result != ConnectivityStatus.none);
    });
  }
}
