// 🎯 Dart imports:

// 🐦 Flutter imports:
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:path_provider/path_provider.dart';

// 📦 Package imports:
import 'package:share_plus/share_plus.dart';
import 'package:universal_html/html.dart' as html;
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/src/config/config.dart';

String vFileTypeToMimeType(VFileType fileType) {
  final convertTypes = {
    VFileType.jpg: 'image/jpg',
    VFileType.png: 'image/png',
    VFileType.csv: 'text/csv',
    VFileType.xlsx: 'text/xlsx',
    VFileType.mp4: 'video/mp4',
    VFileType.pdf: 'application/pdf',
  };
  return convertTypes[fileType]!;
}

class Download {
  Download._();

  static Future<Uint8List> fileFromTheNetwork(String url) async {
    final response = await HttpRetry().get(
      url,
      responseType: HttpRetryResponseType.bytes,
    );
    if (response.data == null) throw 'Cannot save file';
    return response.data;
  }

  static Future<void> memory({
    required Uint8List data,
    required VFileType fileType,
    String? name,
  }) async {
    await _onBytes(
      fileType: fileType,
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> asset({
    required String assetPath,
    required VFileType fileType,
    String? name,
  }) async {
    final imageData = await rootBundle.load(assetPath);

    await _onBytes(
      fileType: fileType,
      bytes: imageData.buffer.asUint8List(),
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> storage({
    required String path,
    required VFileType fileType,
    String? name,
  }) async {
    final data = await VertticeUI.instance.getStorageData(path: path);
    if (data == null) throw 'Cannot save file';

    await _onBytes(
      fileType: fileType,
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> network({
    required String url,
    required VFileType fileType,
    String? name,
  }) async {
    final response = await fileFromTheNetwork(url);

    await _onBytes(
      fileType: fileType,
      bytes: response,
      filename:
          "${name ?? Dates.formatDataAndTime(milliseconds: DateTime.now().millisecondsSinceEpoch)}.${fileType.name}",
    );
  }
}

_onBytes({
  required String filename,
  required Uint8List bytes,
  required VFileType fileType,
}) async {
  if (kIsWeb) {
    filename = filename.replaceAll('/', '_').replaceAll('\\', '_');
    final base64 = base64Encode(bytes);
    final anchor =
        html.AnchorElement(href: 'data:application/octet-stream;base64,$base64')
          ..target = 'blank';
    anchor.download = filename;
    html.document.body?.append(anchor);
    anchor.click();
    anchor.remove();
    return;
  }
  final path = (await getTemporaryDirectory()).path;
  XFile file = XFile(
    path,
    bytes: bytes,
  );

  await Share.shareXFiles(
    [file],
    text: filename,
    subject: "Share a file",
  );
}
