import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class EnterToSubmit extends StatefulWidget {
  final Widget child;
  final VoidCallback runOnSubmit;
  const EnterToSubmit({
    super.key,
    required this.child,
    required this.runOnSubmit,
  });

  @override
  State<EnterToSubmit> createState() => _EnterToSubmitState();
}

class _EnterToSubmitState extends State<EnterToSubmit> {
  final FocusNode _focusNode = FocusNode();

  @override
  void dispose() {
    _focusNode.dispose();
    super.dispose();
  }

  KeyEventResult _handleKeyEvent(FocusNode node, RawKeyEvent event) {
    print(event.physicalKey);

    if (event.physicalKey == PhysicalKeyboardKey.enter) {
      widget.runOnSubmit();
    }

    return event.physicalKey == PhysicalKeyboardKey.enter
        ? KeyEventResult.handled
        : KeyEventResult.ignored;
  }

  @override
  Widget build(BuildContext context) {
    return Focus(
      focusNode: _focusNode,
      onKey: _handleKeyEvent,
      canRequestFocus: true,
      // autofocus: true,
      child: Builder(
        builder: (BuildContext context) {
          if (!_focusNode.hasFocus) {
            return GestureDetector(
              onTap: () {
                FocusScope.of(context).requestFocus(_focusNode);
              },
              child: widget.child,
            );
          }
          return widget.child;
        },
      ),
    );
  }
}
