// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedCircleAvatar extends StatelessWidget {
  final Widget? child;
  final Color? backgroundColor;
  final ImageProvider? backgroundImage;
  final double? radius;
  final BoxFit fit;
  const ThemedCircleAvatar({
    Key? key,
    this.child,
    this.backgroundColor,
    this.backgroundImage,
    this.radius,
    this.fit = BoxFit.scaleDown,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer(builder: (
      BuildContext context,
      ref,
      Widget? _,
    ) {
      final vertticeUIPreference = ref.watch(vertticeUIPreferenceProvider);
      return FittedBox(
        fit: fit,
        child: ConstrainedBox(
          constraints: const BoxConstraints(minWidth: 20, minHeight: 20),
          child: Container(
            decoration: BoxDecoration(
              color: backgroundColor ??
                  (vertticeUIPreference.isDarkTheme
                      ? Colors.grey[850]
                      : Colors.white),
              image: backgroundImage != null
                  ? DecorationImage(image: backgroundImage!)
                  : null,
              borderRadius: BorderRadius.all(
                Radius.circular(radius ?? 50),
              ),
              border: Border.all(
                width: 2,
                color: vertticeUIPreference.themedColors.accentColor,
                style: BorderStyle.solid,
              ),
            ),
            child: Center(
              child: Padding(
                padding: const EdgeInsets.all(1.5),
                child: child,
              ),
            ),
          ),
        ),
      );
    });
  }
}
