// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedIconButton extends StatelessWidget {
  final VoidCallback onPressed;
  final Icon icon;
  final bool? isOffMode;
  final String? tooltip;
  const ThemedIconButton({
    Key? key,
    required this.onPressed,
    required this.icon,
    this.isOffMode,
    this.tooltip,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer(builder: (
      BuildContext context,
      ref,
      Widget? _,
    ) {
      final vertticeUIPreference = ref.watch(vertticeUIPreferenceProvider);
      return Tooltip(
        message: tooltip ?? '',
        showDuration: Duration(milliseconds: tooltip == null ? 0 : 1500),
        child: FittedBox(
          fit: BoxFit.scaleDown,
          child: IconButton(
            onPressed: isOffMode != null && isOffMode! ? () {} : onPressed,
            icon: Icon(
              icon.icon,
              size: icon.size ?? 20,
              color: isOffMode != null && isOffMode!
                  ? Colors.grey
                  : (icon.color ??
                      vertticeUIPreference.themedColors.accentColor),
            ),
          ),
        ),
      );
    });
  }
}
