// 🐦 Flutter imports:
import 'package:flutter/material.dart';
// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedOutlinedText extends StatelessWidget {
  final String text;
  final Color? outlineColor;
  final double outlineWidth;
  final TextStyle? style;
  final TextOverflow? overflow;
  final int? maxLines;
  final Color? color;
  const ThemedOutlinedText(
    this.text, {
    Key? key,
    this.style,
    this.outlineColor,
    this.overflow,
    this.maxLines,
    this.color,
    this.outlineWidth = 1.5,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer(builder: (context, ref, _) {
      final vertticeUIPreference = ref.watch(vertticeUIPreferenceProvider);
      return FittedBox(
        fit: BoxFit.scaleDown,
        child: Stack(
          children: <Widget>[
            Text(
              text,
              style: TextStyle(
                foreground: Paint()
                  ..style = PaintingStyle.stroke
                  ..strokeWidth = outlineWidth
                  ..color = outlineColor ??
                      (vertticeUIPreference.isDarkTheme
                          ? Colors.white
                          : Colors.black),
              ).merge(style),
              overflow: overflow,
              maxLines: maxLines,
            ),
            Text(
              text,
              style: TextStyle(
                color: color ??
                    (!vertticeUIPreference.isDarkTheme
                        ? Colors.white
                        : Colors.black),
              ).merge(style),
              overflow: overflow,
              maxLines: maxLines,
            ),
          ],
        ),
      );
    });
  }
}
